-- Addon Variables --
Notepad = {
	version = "0.04",
	context = nil,
	interface = nil,
    visible = false,
    author = "TimeBomb",
    updatedby = "Valixx",
    environment = "3.7",
}
Notepad_Config = {
        width = 750,
        height = 550,
        alpha = 0.70,
        x = 325,
        y = 200,
}
Notepad_Profiles = { default = "Please insert your text here." }
Notepad_CurrentProfile = "default"

function Notepad.CreateGUI()
	local gui = {}
	gui.frame = UI.CreateFrame("SimpleWindow", "", Notepad.context)
    gui.frame:SetVisible(false)
    gui.frame:SetLayer(1)
    gui.frame:SetCloseButtonVisible(true)
	gui.frame:SetPoint("TOPLEFT", UIParent, "TOPLEFT", Notepad_Config.x, Notepad_Config.y)
	gui.frame:SetWidth(Notepad_Config.width)
    gui.frame:SetHeight(Notepad_Config.height)

    gui.textArea = UI.CreateFrame("SimpleTextArea", "textarea", gui.frame)
    gui.textArea:SetLayer(10)
    gui.textArea:SetPoint("TOPLEFT", gui.frame, "TOPLEFT", 30, 66)
    gui.textArea:SetWidth(Notepad_Config.width - 60)
    gui.textArea:SetHeight(Notepad_Config.height - 125)
    gui.textArea:SetBackgroundColor(0.0, 0.0, 0.0, 0.3)
    if Notepad_CurrentProfile ~= "" then
        gui.textArea:SetText(Notepad_Profiles[Notepad_CurrentProfile])
    else
        gui.textArea:SetText("") -- Must have at least one empty space for it to work correctly.
	end

    gui.textField = UI.CreateFrame("RiftTextfield", "Textfield", gui.frame)
    gui.textField:SetLayer(10)
    gui.textField:SetPoint("TOPLEFT", gui.frame, "TOPLEFT", 50, Notepad_Config.height - 45)
    gui.textField:SetWidth(200)
    gui.textField:SetText(Notepad_CurrentProfile)
    gui.textField:SetBackgroundColor(0.3, 0.3, 0.3)

    gui.saveBtn = UI.CreateFrame("RiftButton", "buttonsave", gui.frame)
    gui.saveBtn:SetLayer(10)
    gui.saveBtn:SetPoint("TOPLEFT", gui.frame, "TOPLEFT", 275, Notepad_Config.height - 52)
    gui.saveBtn:SetText("Save")

    gui.loadBtn = UI.CreateFrame("RiftButton", "buttonload", gui.frame)
    gui.loadBtn:SetLayer(10)
    gui.loadBtn:SetPoint("TOPLEFT", gui.frame, "TOPLEFT", 425, Notepad_Config.height - 52)
    gui.loadBtn:SetText("Load")

    function gui.frame.Event:Close()
        Notepad.ToggleVisibility()
    end

    function gui.saveBtn.Event:LeftClick()
        local profileName = gui.textField:GetText()
        local text = gui.textArea:GetText()
        Notepad_Profiles[profileName] = text
        Notepad_CurrentProfile = profileName
        print("Text successfully saved to profile: " .. profileName .. ".")
    end

    function gui.loadBtn.Event:LeftClick()
        local profileName = gui.textField:GetText()
        if not Notepad_Profiles[profileName] then
            print("Error. Profile " .. profileName .. " not found.")
        else
            gui.textArea:SetText(Notepad_Profiles[profileName])
            Notepad_CurrentProfile = profileName
            print("Profile: " .. profileName .. " successfully loaded.")
        end
    end

	return gui
end

-- Initial setup --
function Notepad.Init(addon)
	if addon == "Notepad" then
		Notepad.context = UI.CreateContext("Notepad")

		Notepad.interface = Notepad.CreateGUI()

        if Notepad_CurrentProfile ~= "" then
            if not Notepad_Profiles[Notepad_CurrentProfile] then
                Notepad_CurrentProfile = ""
                print("Warning - There was a problem loading profile: " .. Notepad_CurrentProfile .. ". Profile not found.\nLoaded! Type /notepad to show Notepad.")
            else
                print("Loaded! Type /notepad to show Notepad.\nCurrent Profile: " .. Notepad_CurrentProfile .. ". Current Version: " .. Notepad.version .. ". Updated by " .. Notepad.updatedby .. " for environment " .. Notepad.environment .. ".")
            end
        end


	end
end

function Notepad.ToggleVisibility()
    if not Notepad.visible then
        Notepad.interface.frame:SetVisible(true)
    else
        Notepad_Config.y = Notepad.interface.frame:GetTop()
        Notepad_Config.x = Notepad.interface.frame:GetLeft()
        Notepad.interface.frame:SetVisible(false)
    end
    Notepad.visible = not Notepad.visible
end

function Notepad.SlashHandler(args)
    if args ~= "reset" then
        Notepad.ToggleVisibility()
    else
        if Notepad.visible then
            Notepad.ToggleVisibility()
        end
        Notepad_Config.x = 325
        Notepad_Config.y = 200
        Notepad.interface = Notepad.CreateGUI()
        print("Notepad reset.")
    end
end

-- Starting up... Register Events --
table.insert(Event.Addon.Load.End, {Notepad.Init, "Notepad", "Initital Setup"})
table.insert(Command.Slash.Register("notepad"), {Notepad.SlashHandler, "Notepad", "Slash Command"})
